@@ -17,18 +17,20 @@ module TTFunk
       def unicode
         # Because most callers just call .first on the result, put tables with
         # highest-number format first. Unsupported formats will be ignored.
-        @unicode ||= @tables
-                     .select { |table| table.unicode? && table.supported? }
-                     .sort { |a, b| b.format <=> a.format }
+        @unicode ||=
+          @tables
+            .select { |table| table.unicode? && table.supported? }
+            .sort { |a, b| b.format <=> a.format }
       end
 
       private
 
       def parse!
         @version, table_count = read(4, 'nn')
-        @tables = Array.new(table_count) do
-          Cmap::Subtable.new(file, offset)
-        end
+        @tables =
+          Array.new(table_count) do
+            Cmap::Subtable.new(file, offset)
+          end
       end
     end
   end
