@@ -18,12 +18,13 @@ module TTFunk
           glyph_indexes = Array.new(256, 0)
           glyph_map = { 0 => 0 }
 
-          new_map = charmap.keys.sort.each_with_object({}) do |code, map|
-            glyph_map[charmap[code]] ||= next_id += 1
-            map[code] = { old: charmap[code], new: glyph_map[charmap[code]] }
-            glyph_indexes[code] = glyph_map[charmap[code]]
-            map
-          end
+          new_map =
+            charmap.keys.sort.each_with_object({}) do |code, map|
+              glyph_map[charmap[code]] ||= next_id += 1
+              map[code] = { old: charmap[code], new: glyph_map[charmap[code]] }
+              glyph_indexes[code] = glyph_map[charmap[code]]
+              map
+            end
 
           # format, length, language, indices
           subtable = [0, 262, 0, *glyph_indexes].pack('nnnC*')
