@@ -15,10 +15,11 @@ module TTFunk
       # * :table - the string representing the table's contents
       # * :type  - the type of offset (to be encoded in the 'head' table)
       def self.encode(offsets)
-        long_offsets = offsets.any? do |offset|
-          short_offset = offset / 2
-          short_offset * 2 != offset || short_offset > 0xffff
-        end
+        long_offsets =
+          offsets.any? do |offset|
+            short_offset = offset / 2
+            short_offset * 2 != offset || short_offset > 0xffff
+          end
 
         if long_offsets
           { type: 1, table: offsets.pack('N*') }
@@ -38,10 +39,10 @@ module TTFunk
       private
 
       def parse!
-        type = file.header.index_to_loc_format == 0 ? 'n' : 'N'
+        type = file.header.index_to_loc_format.zero? ? 'n' : 'N'
         @offsets = read(length, "#{type}*")
 
-        if file.header.index_to_loc_format == 0
+        if file.header.index_to_loc_format.zero?
           @offsets.map! { |v| v * 2 }
         end
       end
