@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module TTFunk
   class Table
     class Post
@@ -8,9 +10,9 @@ module TTFunk
 
         private
 
-          def parse_format!
-            @map = read(file.maximum_profile.num_glyphs * 2, "N*")
-          end
+        def parse_format!
+          @map = read(file.maximum_profile.num_glyphs * 2, 'N*')
+        end
       end
     end
   end
