@@ -5,7 +5,7 @@ require 'rspec'
 
 # Requires supporting ruby files with custom matchers and macros, etc,
 # in spec/extensions/ and its subdirectories.
-Dir[File.dirname(__FILE__) + '/support/**/*.rb'].sort.each { |f| require f }
+Dir[File.expand_path('support/**/*.rb', __dir__)].sort.each { |f| require f }
 
 RSpec.configure do |config|
   config.include PathHelpers
